pub enum CompleteRoundError<CompleteErr, SendErr> {
CompleteRound(CompleteErr),
Send(SendErr),
Echo(EchoError),
}Available on crate feature
echo-broadcast only.Expand description
An error returned in round completion
Variants
CompleteRound(CompleteErr)
Error occurred while handling received message(s)
Send(SendErr)
Error occurred while sending a message to another party
The only message we send during round completion is echo message
Echo(EchoError)
Echo broadcast sub-protocol error