RoundStoreExt

Trait RoundStoreExt 

pub trait RoundStoreExt: RoundStore {
    // Required methods
    fn read_prop<P: Any>(&self) -> Option<P>;
    fn set_prop<P: Clone + 'static>(self, value: P) -> WithProp<P, Self>;
}
Extra functionalities defined for any RoundStore

Required Methods

fn read_prop<P: Any>(&self) -> Option<P>

Reads a property P of the store

Returns Some(property_value) if this store exposes property P, otherwise returns None

fn set_prop<P: Clone + 'static>(self, value: P) -> WithProp<P, Self>

Constructs a new store that exposes property P with provided value

If store already provides a property P, it will be overwritten

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors