pub enum Msg<D: Digest, M> {
Echo {
round: u16,
hash: Output<D>,
},
Main(M),
}Available on crate feature
echo-broadcast only.Expand description
Message of the protocol with echo broadcast round(s)
Variants
Echo
Message from echo broadcast sub-protocol
Fields

round: u16Indicates for which round of main protocol this echo message is transmitted
Note that this field is controlled by potential malicious party. If it sets it to the round that doesn’t exist, the protocol will likely be aborted with an error that we received a message from unregistered round, which may appear as implementation error (i.e. API misuse), but in fact it’s a malicious abort.
Main(M)
Message from the main protocol