pub struct EchoError(/* private fields */);Available on crate feature
echo-broadcast only.Expand description
An error in echo-broadcast sub-protocol
It may indicate that reliability check was not successful, or some other error, for instance, that a round that requires reliable broadcast behaves unexpectedly (e.g. if we received two messages from the same party and the main round didn’t return an error).
Implementations